@@ -107,8 +107,11 @@ class _handler_extension:
     def FormattedMessage(
         self, record: lggg.LogRecord, /
     ) -> tuple[str, list[str] | None]:
-        """"""
-        # "message" is not yet an attribute of record (it will be set by format()); Use "msg" instead.
+        """
+        Note: "message" is not yet an attribute of record (it will be set by format()); Use "msg" instead.
+        """
+        if not isinstance(record.msg, str):
+            record.msg = str(record.msg)
         if "\n" in record.msg:
             original_message = record.msg
             lines = original_message.splitlines()
